<?php
namespace Src\TableGateways;

class ReleveGateway {

    private $db = null;

    public function __construct($db)
    {
        $this->db = $db;
    }

    public function findAll()
    {
        $statement = "
            SELECT 
                id, libelle
            FROM
                releve;
        ";

        try {
            $statement = $this->db->query($statement);
            $result = $statement->fetchAll(\PDO::FETCH_ASSOC);
            return $result;
        } catch (\PDOException $e) {
            exit($e->getMessage());
        }
    }

    public function find($id)
    {
        $statement = "
            SELECT 
                id, libelle
            FROM
                releve
            WHERE id = ?;
        ";

        try {
            $statement = $this->db->prepare($statement);
            $statement->execute(array($id));
            $result = $statement->fetchAll(\PDO::FETCH_ASSOC);
            return $result;
        } catch (\PDOException $e) {
            exit($e->getMessage());
        }    
    }

    public function insert(Array $input)
    {
        $statement = "
            INSERT INTO releve 
                (num, dateHeure_releve, valeur_compteur_1)
            VALUES
                (:libelle, :dateHeure_releve, :valeur_compteur_1);
        ";

        try {
            $statement = $this->db->prepare($statement);
            $statement->execute(array(
                'libelle' => $input['libelle'],
                'dateHeure_releve' => $input['dateHeure_releve'],
                'valeur_compteur_1' => $input['valeur_compteur_1'],
            ));
            return $statement->rowCount();
        } catch (\PDOException $e) {
            exit($e->getMessage());
        }    
    }

    public function update($id, Array $input)
    {
        $statement = "
            UPDATE releve
            SET 
                libelle = :libelle
                dateHeure_releve = :dateHeure_releve
                valeur_compteur_1 = :valeur_compteur_1
            WHERE id = :id;
        ";

        try {
            $statement = $this->db->prepare($statement);
            $statement->execute(array(
                'id' => (int) $id,
                'libelle' => $input['libelle'],
                'dateHeure_releve' => $input['dateHeure_releve'],
                'valeur_compteur_1' => $input['valeur_compteur_1'],
            ));
            return $statement->rowCount();
        } catch (\PDOException $e) {
            exit($e->getMessage());
        }    
    }

    public function delete($id)
    {
        $statement = "
            DELETE FROM releve, dateHeure_releve, valeur_compteur_1
            WHERE id = :id;
        ";

        try {
            $statement = $this->db->prepare($statement);
            $statement->execute(array('id' => $id));
            return $statement->rowCount();
        } catch (\PDOException $e) {
            exit($e->getMessage());
        }    
    }
}

